@@ -109,9 +109,6 @@ collapse2.array <- function(x, keep, method = c("mean", "sum"), ...){
 #' @param filebase where to store the output; default is \code{NULL} and is
 #' automatically determined
 #' @param hybrid whether the array will be
-#' @param signal_types signal types to perform baseline corrections; applied
-#' to power repository object produced by \code{\link{prepare_subject_power}};
-#' default is \code{'LFP'}
 #' @param electrodes the electrodes to be included in baseline calculation;
 #' for power repository object produced by \code{\link{prepare_subject_power}}
 #' only; default is all available electrodes in each of \code{signal_types}
@@ -191,21 +188,25 @@ power_baseline.rave_prepare_power <- function(
   x, baseline_windows,
   method = c("percentage", "sqrt_percentage", "decibel", "zscore", "sqrt_zscore"),
   units = c("Frequency", "Trial", "Electrode"),
-  signal_types = "LFP", electrodes, ...
+  electrodes, ...
 ){
   method <- match.arg(method)
   force(baseline_windows)
 
-  if(is.na(signal_types)){
-    signal_types <- names(x$power)
-  }
   if(missing(electrodes)){
     electrodes <- x$electrode_list
+  } else {
+    electrodes <- electrodes[electrodes %in% x$electrode_list]
+    if(!length(electrodes)) {
+      stop("`power_baseline`: none of electrodes specified can be found in the loaded repository")
+    }
   }
 
-  if(!inherits(x$baselined, "fastmap2")){
-    x$baselined <- dipsaus::fastmap2()
-  }
+  signal_type <- x$signal_type
+
+  # if(!inherits(x$baselined, "fastmap2")){
+  #   x$baselined <- dipsaus::fastmap2()
+  # }
 
   # Prepare global variables
   baseline_windows <- validate_time_window(baseline_windows)
@@ -215,87 +216,83 @@ power_baseline.rave_prepare_power <- function(
   }
   unit_dims <- c(1L, 3L, 4L)[c("Frequency", "Trial", "Electrode") %in% units]
 
-  for(signal_type in signal_types){
-    sub <- x$power[[signal_type]]
-    sel <- sub$electrodes %in% electrodes
+  sel <- x$electrode_list %in% electrodes
 
-    # contains no electrode
-    if(!any(sel)){
-      x$baselined$`@remove`(signal_type)
-      next
-    }
+  sub_list <- x$power$data_list[sel]
+  sub_elec <- x$electrode_list[sel]
 
-    sub_list <- sub$data_list[sel]
-    sub_elec <- sub$electrodes[sel]
+  # dm <- dim(sub_list[[1]])
+  # dm[[4]] <- length(sub_elec)
 
-    dnames <- dimnames(sub_list[[1]])
-    dnames$Electrode <- sub_elec
-    dm <- dim(sub_list[[1]])
-    dm[[length(dm)]] <- length(sub_elec)
-    time_index <- unique(unlist(lapply(baseline_windows, function(w){
-      which(dnames$Time >= w[[1]] & dnames$Time <= w[[2]])
-    })))
+  time_index <- unique(unlist(lapply(baseline_windows, function(w){
+    which(x$power$dimnames$Time >= w[[1]] & x$power$dimnames$Time <= w[[2]])
+  })))
 
-    # calculate signature
-    digest_key <- list(
-      input_signature = sub$signature,
+  # calculate signature
+  digest_key <- list(
+    input_signature = x$power$signature,
+    signal_type = signal_type,
+    rave_data_type = "power",
+    method = method,
+    unit_dims = unit_dims,
+    time_index = time_index,
+    dimension = x$power$dim
+  )
+
+  signature <- dipsaus::digest(digest_key)
+
+  filebase <- file.path(cache_root(), "_baselined_arrays_", x$power$signature)
+  res <- tryCatch({
+    res <- filearray::filearray_checkload(
+      filebase, mode = "readwrite", symlink_ok = FALSE,
+      rave_signature = signature,
       signal_type = signal_type,
-      rave_data_type = "power",
-      method = method,
-      unit_dims = unit_dims,
-      time_index = time_index,
-      dimension = dm
+      rave_data_type = "power-baselined",
+      ready = TRUE,  # The rest procedure might go wrong, in case failure
+      RAVEIO_FILEARRAY_VERSION = RAVEIO_FILEARRAY_VERSION
     )
-
-    signature <- dipsaus::digest(digest_key)
-
-    output <- x$baselined[[signal_type]]
-    if(inherits(output, "FileArray")){
-      filebase <- output$.filebase
-    } else {
-      filebase <- file.path(cache_root(), "_baselined_arrays_", signature)
-    }
-
-    res <- tryCatch({
-      res <- filearray::filearray_checkload(
-        filebase, mode = "readwrite", symlink_ok = FALSE,
-        rave_signature = signature,
-        signal_type = signal_type,
-        rave_data_type = "power-baselined",
-        ready = TRUE,  # The rest procedure might go wrong, in case failure
-        RAVEIO_FILEARRAY_VERSION = RAVEIO_FILEARRAY_VERSION
-      )
-      # No need to baseline again, the settings haven't changed
-      x$baselined[[signal_type]] <- res
-      # message("Using existing cache")
-      next
-    }, error = function(e){
-      # message(e$message)
-      if(dir.exists(filebase)){ unlink(filebase, recursive = TRUE, force = TRUE) }
-      dir_create2(dirname(filebase))
-      res <- filearray::filearray_create(filebase, dm, type = "float", partition_size = 1)
-      res$.mode <- "readwrite"
-      res$.header$rave_signature <- signature
-      res$.header$signal_type <- signal_type
-      res$.header$rave_data_type <- "power-baselined"
-      res$.header$baseline_method <- method
-      res$.header$unit_dims <- unit_dims
-      res$.header$time_index <- time_index
-      res$.header$baseline_windows <- baseline_windows
-      res$.header$RAVEIO_FILEARRAY_VERSION <- RAVEIO_FILEARRAY_VERSION
-      res$.header$ready <- FALSE
-      dimnames(res) <- dnames
+    catgl("Using existing cache", level = "DEBUG")
+    res
+  }, error = function(e){
+    # message(e$message)
+    if(dir.exists(filebase)){ unlink(filebase, recursive = TRUE, force = TRUE) }
+    dir_create2(dirname(filebase))
+    res <- filearray::filearray_create(
+      filebase = filebase,
+      dimension = x$power$dim,
+      type = "float",
+      partition_size = 1
+    )
+    res$.mode <- "readwrite"
+    res$.header$rave_signature <- signature
+    res$.header$signal_type <- signal_type
+    res$.header$rave_data_type <- "power-baselined"
+    res$.header$baseline_method <- method
+    res$.header$unit_dims <- unit_dims
+    res$.header$time_index <- time_index
+    res$.header$baseline_windows <- baseline_windows
+    res$.header$RAVEIO_FILEARRAY_VERSION <- RAVEIO_FILEARRAY_VERSION
+    res$.header$ready <- FALSE
+    dimnames(res) <- x$power$dimnames
       # # automatically run
       # res$.save_header()
-      res
-    })
+    res
+  })
 
-    if("Electrode" %in% units){
-      input_list <- lapply(seq_along(sub_elec), function(ii){
+  if("Electrode" %in% units){
+    # Check electrode with baselines
+    todo_elec <- sub_elec[!sub_elec %in% res$.header$electrodes]
+
+    if(length(todo_elec)) {
+
+      res$set_header("ready", FALSE)
+
+      input_list <- lapply(todo_elec, function(e){
+        idx <- which(x$electrode_list == e)
         list(
-          index = ii,
-          electrode = sub_elec[[ii]],
-          array = sub_list[[ii]]
+          index = idx,
+          electrode = e,
+          array = x$power$data_list[[idx]]
         )
       })
 
@@ -318,31 +315,54 @@ power_baseline.rave_prepare_power <- function(
                   signal_type)
         }
       )
-    } else {
-      bind_base <- file.path(cache_root(), "_binded_arrays_", sub$signature, "power")
-      dir_create2(dirname(bind_base))
-      bind_array <- filearray::filearray_bind(
-        .list = sub$data_list,
-        symlink = symlink_enabled(),
-        filebase = bind_base,
-        overwrite = TRUE, cache_ok = TRUE)
 
-      res[] <- dipsaus::baseline_array(
-        x = bind_array[,,, which(sel),drop=FALSE],
-        along_dim = 2L,
-        baseline_indexpoints = time_index,
-        unit_dims = unit_dims,
-        method = method
+      res$.header$electrodes <- c(
+        res$.header$electrodes,
+        todo_elec
       )
+
+      res$set_header("ready", TRUE)
     }
 
 
-    res$set_header("ready", TRUE)
-    x$baselined[[signal_type]] <- res
+    res$.mode <- "readonly"
+
+  } else {
+
+    stop("Baseline across electrode not supported")
+
   }
 
+  x$power$baselined <- res
   return(x)
-
+#
+#   if("Electrode" %in% units){
+#
+#
+#
+#   } else {
+#
+#     dir_create2(dirname(bind_base))
+#     bind_array <- filearray::filearray_bind(
+#       .list = sub$data_list,
+#       symlink = symlink_enabled(),
+#       filebase = bind_base,
+#       overwrite = TRUE, cache_ok = TRUE)
+#
+#     res[] <- dipsaus::baseline_array(
+#       x = bind_array[,,, which(sel),drop=FALSE],
+#       along_dim = 2L,
+#       baseline_indexpoints = time_index,
+#       unit_dims = unit_dims,
+#       method = method
+#     )
+#   }
+#
+#
+#   res$set_header("ready", TRUE)
+#   x$power$baselined <- res
+#
+#   return(x)
 }
 
 
