@@ -3,13 +3,14 @@ require(testthat)
 test_that("Subject class & derivatives", {
   skip_on_cran()
 
-  on.exit({
-    load_setting()
-  })
+  on.exit({ load_setting() })
 
   raveio_setopt('data_dir', '~/rave_data/data_dir/', .save = FALSE)
   raveio_setopt('raw_data_dir', '~/rave_data/raw_dir/', .save = FALSE)
   raveio_setopt('file_structure', 'native', .save = FALSE)
+
+  skip_if_not("demo" %in% get_projects())
+
   sub <- as_rave_subject('demo/YAB')
 
 
@@ -30,4 +31,7 @@ test_that("Subject class & derivatives", {
     'demo/YAB'
   )
 
+  load_setting()
+  on.exit({})
+
 })
